@@ -84,20 +84,14 @@ class Starter(object):
             self.terminate()
         if not synch:
             return
-        for i in range(wait_seconds):
-            _log.debug('Waiting for server %s to get stopped. Iteration: %d' %
-                       (self.ds_name, i))
-            if self.isRunning():
-                time.sleep(1)
-            else:
-                ##############################################################
-                # TODO: this workaround doesn't seem necessary (see isRunning)
-                # time.sleep(3)
-                ##############################################################
-                _log.info('Server %s has been stopped' % self.ds_name)
-                return
-        _log.warning('Server %s did not stop within %d seconds' %
-                     (self.ds_name, wait_seconds))
+        _log.debug('Waiting for server %s to get stopped' % self.ds_name)
+        try:
+            self.process.wait(wait_seconds)
+        except subprocess.TimeoutExpired:
+            _log.warning('Server %s did not stop within %d seconds' %
+                         (self.ds_name, wait_seconds))
+        else:
+            _log.info('Server %s has been stopped' % self.ds_name)
 
     def startDs(self, synch=True, wait_seconds=10):
         if self.isRunning():
@@ -217,13 +211,19 @@ class ProcessStarter(Starter):
 
     def terminate(self):
         if self.process:
-            self.process.terminate()
+            try:
+                self.dserver.Kill()
+            except:
+                self.process.terminate()
         else:
             _log.warning('Process not started, cannot terminate it.')
 
     def hardKill(self):
         if self.process:
-            self.process.kill()
+            try:
+                self.dserver.Kill()  # no hard kill in Tango DS, simply kill it
+            except:
+                self.process.kill()
         else:
             _log.warning('Process not started, cannot terminate it.')
 
