@@ -149,6 +149,10 @@ class TangoFactory(Singleton, TaurusFactory, Logger):
             v.cleanUp()
         for k, v in self.tango_db.items():
             v.cleanUp()
+        try:
+            util = PyTango.Util.instance(False)
+        except PyTango.DevFailed:
+            PyTango.ApiUtil.cleanup()
         self.reInit()
 
     def getExistingAttributes(self):
