@@ -25,14 +25,13 @@
 #############################################################################
 
 """This module provides a taurus QPushButton based widgets"""
+from __future__ import print_function
 
-__all__ = ["TaurusLauncherButton", "TaurusCommandButton", "TaurusLockButton"]
+from builtins import map
+from builtins import str
+from future.utils import string_types
 
-__docformat__ = 'restructuredtext'
-
-import PyTango
-
-from taurus.external.qt import Qt
+from taurus.external.qt import Qt, compat
 from taurus.core.taurusbasetypes import LockStatus, TaurusLockInfo
 from taurus.core.taurusdevice import TaurusDevice
 from taurus.qt.qtgui.base import TaurusBaseWidget
@@ -40,6 +39,11 @@ from taurus.core.util import eventfilters
 from taurus.qt.qtgui.dialog import ProtectTaurusMessageBox
 
 
+__all__ = ["TaurusLauncherButton", "TaurusCommandButton", "TaurusLockButton"]
+
+__docformat__ = 'restructuredtext'
+
+
 class _ButtonDialog(Qt.QDialog):
     _widget = None
     deleteWidgetOnClose = False
@@ -93,11 +97,6 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
         button =  TaurusLauncherButton(widget = TaurusLabel())
         button.setModel('a/b/c/attrname') # attr name, which will be set at the TaurusLabel when clicking
 
-        #same as the previous one, but using the parent model and putting a custom text and icon:
-        button =  TaurusLauncherButton(widget = TaurusLabel(), text='click me', icon='logos:taurus.png')
-        button.setUseParentModel(True)  #let's assume that the button's parent has a model of type "/a/b/c"
-        button.setModel('/attrname')
-
     '''
 
     _widgetClassName = ''
@@ -181,7 +180,7 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
         if self._dialog.previousWidgetConfig is not None:
             try:
                 widget.applyConfig(self._dialog.previousWidgetConfig)
-            except Exception, e:
+            except Exception as e:
                 self.warning(
                     'Cannot apply previous configuration to widget. Reason: %s', repr(e))
 
@@ -265,8 +264,8 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
 
     .. seealso:: :class:`TaurusCommandsForm` provides a good example of use of
                  TaurusCommandButton (including managing the return value) '''
-
-    commandExecuted = Qt.pyqtSignal(object)
+    # TODO: tango-centric
+    commandExecuted = Qt.pyqtSignal(compat.PY_OBJECT)
 
     def __init__(self, parent=None, designMode=False, command=None,
                  parameters=None, icon=None, text=None,
@@ -349,7 +348,7 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
                 modelobj.set_timeout_millis(int(self._timeout * 1000))
             result = modelobj.command_inout(self._command, self._castParameters(
                 self._parameters, self._command, modelobj))
-        except Exception, e:
+        except Exception as e:
             self.error('Unexpected error when executing command %s of %s: %s' % (
                 self._command, modelobj.getNormalName(), str(e)))
             raise
@@ -372,6 +371,8 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
 
         :return: (sequence or scalar) a sequence of parameters (or a scalar if only one parameter)
         '''
+        import PyTango
+
         if parameters is None:
             parameters = self._parameters
         if command is None:
@@ -381,7 +382,7 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
 
         try:
             param_type = dev.command_query(command).in_type
-        except Exception, e:
+        except Exception as e:
             self.warning(
                 'Cannot get parameters info for command %s:%s' % (command, str(e)))
             return parameters
@@ -405,7 +406,7 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
             else:
                 return parameters
         else:
-            return map(cast_type, parameters)
+            return list(map(cast_type, parameters))
 
     def setCommand(self, commandName):
         '''sets the command to be executed when the button is clicked
@@ -444,7 +445,7 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
                            quotes will be removed and the quoted text will not
                            be splitted.
         '''
-        if isinstance(parameters, (basestring, Qt.QString)):
+        if isinstance(parameters, string_types):
             parameters = str(parameters).strip()
             if parameters[0] in ('"', "'") and parameters[0] == parameters[-1]:
                 parameters = [parameters[1:-1]]
@@ -545,10 +546,10 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
 
 class TaurusLockButton(Qt.QPushButton, TaurusBaseWidget):
 
-    _LOCK_MAP = {LockStatus.Unlocked: "extra_icon:lock_unlocked.svg",
-                 LockStatus.Locked: "extra_icon:lock_locked_unpreviledged.svg",
-                 LockStatus.LockedMaster: "extra_icon:lock_locked.svg",
-                 LockStatus.Unknown: "extra_icon:lock_unknown.svg"}
+    _LOCK_MAP = {LockStatus.Unlocked: "extra_icons:lock_unlocked.svg",
+                 LockStatus.Locked: "extra_icons:lock_locked_unpreviledged.svg",
+                 LockStatus.LockedMaster: "extra_icons:lock_locked.svg",
+                 LockStatus.Unknown: "extra_icons:lock_unknown.svg"}
 
     def __init__(self, parent=None, designMode=False):
         self._lock_info = TaurusLockInfo()
@@ -637,7 +638,7 @@ def lockButtonMain():
     if len(args) == 0:
         w = demo()
     else:
-        models = map(str.lower, args)
+        models = list(map(str.lower, args))
 
         w = Qt.QWidget()
         layout = Qt.QGridLayout()
@@ -658,7 +659,7 @@ def commandButtonMain():
     import sys
     from taurus.qt.qtgui.application import TaurusApplication
 
-    app = TaurusApplication()
+    app = TaurusApplication(cmd_line_parser=None)
     form = TaurusCommandButton(parent=None, designMode=False, command='DevBoolean', parameters=[
                                123], icon='logos:taurus.png', text='launch: DevBoolean 123')
     form.setModel('sys/tg_test/1')
@@ -666,7 +667,7 @@ def commandButtonMain():
         'Booo scary command!!\n Maybe you should think twice!')
 
     def f(*a):
-        print a
+        print(a)
     form.commandExecuted.connect(f)
     form.show()
     sys.exit(app.exec_())
@@ -676,7 +677,7 @@ def launcherButtonMain():
     import sys
     from taurus.qt.qtgui.application import TaurusApplication
 
-    app = TaurusApplication()
+    app = TaurusApplication(cmd_line_parser=None)
 
     # Creating button giving the widget
     # from taurus.qt.qtgui.plot import TaurusPlot
